@@ -9,7 +9,7 @@
 #include <string.h>
 #include <stdarg.h>
 
-#define SPVM_NATIVE_VERSION_NUMBER 0.989058
+#define SPVM_NATIVE_VERSION_NUMBER 0.989060
 
 #define SPVM_NATIVE_CREATE_VERSION_STRING_STRINGIFY(x) #x
 
@@ -23,6 +23,8 @@
 
 #define spvm_warn(format, ...) fprintf(stderr, format "\n", ##__VA_ARGS__)
 
+#define spvm_warnf(stream, format, ...) fprintf(stream, format "\n", ##__VA_ARGS__)
+
 typedef union spvm_value SPVM_VALUE;
 
 struct spvm_env;
@@ -318,12 +320,9 @@ struct spvm_env {
   int32_t (*get_memory_blocks_count)(SPVM_ENV* env, SPVM_VALUE* stack);
   void (*say)(SPVM_ENV* env, SPVM_VALUE* stack, void* string);
   void (*warn)(SPVM_ENV* env, SPVM_VALUE* stack, void* string, const char* class_dir, const char* class_rel_file, int32_t line);
-  void* (*new_mutex)(SPVM_ENV* env, SPVM_VALUE* stack);
-  void (*free_mutex)(SPVM_ENV* env, SPVM_VALUE* stack, void* mutex);
-  int32_t (*lock)(SPVM_ENV* env, SPVM_VALUE* stack, void* mutex);
-  int32_t (*unlock)(SPVM_ENV* env, SPVM_VALUE* stack, void* mutex);
-  int32_t (*reader_lock)(SPVM_ENV* env, SPVM_VALUE* stack, void* mutex);
-  int32_t (*reader_unlock)(SPVM_ENV* env, SPVM_VALUE* stack, void* mutex);
+  FILE* (*spvm_stdin)(SPVM_ENV* env, SPVM_VALUE* stack);
+  FILE* (*spvm_stdout)(SPVM_ENV* env, SPVM_VALUE* stack);
+  FILE* (*spvm_stderr)(SPVM_ENV* env, SPVM_VALUE* stack);
 };
 
 struct spvm_env_api {
