@@ -1963,6 +1963,24 @@ Prints a string and C<\n> to stdout. This is the same operator as the say operat
 
 Operates the warn operator.
 
+=head2 spvm_stdin
+
+  FILE* (*spvm_stdin)(SPVM_ENV* env, SPVM_VALUE* stack);
+
+Gets the standard input opened for SPVM.
+
+=head2 spvm_stdout
+
+  FILE* (*spvm_stdout)(SPVM_ENV* env, SPVM_VALUE* stack);
+
+Gets the standard output opened for SPVM.
+
+=head2 spvm_stderr
+
+  FILE* (*spvm_stderr)(SPVM_ENV* env, SPVM_VALUE* stack);
+
+Gets the standard error opened for SPVM.
+
 =head1 Native API IDs
 
 Native APIs have its IDs. These IDs are permanently same for the binary compatibility after the future release C<v1.0>.
@@ -2380,6 +2398,17 @@ Examples:
   spvm_warn("Hello");
   spvm_warn("Hello %s%d", "Foo", 3);
 
+=head2 spvm_warnf
+
+  void spvm_warnf(FILE* stream, const char* format, ...)
+
+Prints the formatted message I<format> to the stream I<stream> with a new line.
+
+Examples:
+
+  spvm_warnf(env->api->runtime->get_spvm_stderr(env->runtime), "Hello");
+  spvm_warnf(env->api->runtime->get_spvm_stderr(env->runtime), "Hello %s%d", "Foo", 3);
+
 =head2 SPVM_NATIVE_GET_POINTER
 
 C<#define SPVM_NATIVE_GET_POINTER(object)>
