@@ -947,7 +947,7 @@ int32_t SPVM__TestCase__NativeAPI__native_get_field_int_by_name_exception(SPVM_E
 
 int32_t SPVM__TestCase__NativeAPI__native_get_field_long_by_name(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t error = 0;
-
+  
   void* object = stack[0].oval;
   
   int64_t long_value = env->get_field_long_by_name(env, stack, object, "long_value", &error, __func__, FILE_NAME, __LINE__);
@@ -2264,8 +2264,11 @@ int32_t SPVM__TestCase__NativeAPI__check_native_api_runtime_indexes(SPVM_ENV* en
   if ((void*)&env->api->runtime->build_precompile_module_source != &env_array[6]) { stack[0].ival = 0; return 0; }
   if ((void*)&env->api->runtime->build_precompile_method_source != &env_array[7]) { stack[0].ival = 0; return 0; }
   
-  spvm_warn("Foo %s %d", "aaa", 3);
-  spvm_warn("Foo");
+  spvm_warn("spvm_warn test: %s %d", "aaa", 3);
+  spvm_warn("spvm_warn test:Foo");
+  
+  spvm_warnf(env->api->runtime->get_spvm_stderr(env->runtime), "spvm_warnf test: %s %d", "aaa", 3);
+  spvm_warnf(env->api->runtime->get_spvm_stderr(env->runtime), "spvm_warnf test:Foo");
   
   stack[0].ival = 1;
 
@@ -3016,3 +3019,45 @@ int32_t SPVM__TestCase__NativeAPI__close_stderr(SPVM_ENV* env, SPVM_VALUE* stack
   return 0;
 }
 
+int32_t SPVM__TestCase__NativeAPI__spvm_stdin(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  if (!(env->spvm_stdin(env, stack) == env->api->runtime->get_spvm_stdin(env->runtime))) {
+    
+    stack[0].ival = 0;
+    
+    return 0;
+  }
+  
+  stack[0].ival = 1;
+  
+  return 0;
+}
+
+int32_t SPVM__TestCase__NativeAPI__spvm_stdout(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  if (!(env->spvm_stdout(env, stack) == env->api->runtime->get_spvm_stdout(env->runtime))) {
+    
+    stack[0].ival = 0;
+    
+    return 0;
+  }
+  
+  stack[0].ival = 1;
+  
+  return 0;
+}
+
+int32_t SPVM__TestCase__NativeAPI__spvm_stderr(SPVM_ENV* env, SPVM_VALUE* stack) {
+  
+  if (!(env->spvm_stderr(env, stack) == env->api->runtime->get_spvm_stderr(env->runtime))) {
+    
+    stack[0].ival = 0;
+    
+    return 0;
+  }
+  
+  stack[0].ival = 1;
+  
+  return 0;
+}
+
